summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rwxr-xr-xutil/lint/checkpatch.pl6
1 files changed, 3 insertions, 3 deletions
diff --git a/util/lint/checkpatch.pl b/util/lint/checkpatch.pl
index f1c31c54c08a..41aae935f595 100755
--- a/util/lint/checkpatch.pl
+++ b/util/lint/checkpatch.pl
@@ -2655,9 +2655,9 @@ sub process {
$commit_log_possible_stack_dump = 1;
}
# Check for line lengths > 75 in commit log, warn once
if ($in_commit_log && !$commit_log_long_line &&
- length($line) > 75 &&
+ length($line) > 72 &&
!($line =~ /^\s*[a-zA-Z0-9_\/\.]+\s+\|\s+\d+/ ||
# file delta changes
$line =~ /^\s*(?:[\w\.\-]+\/)++[\w\.\-]+:/ ||
@@ -2666,7 +2666,7 @@ sub process {
# A Fixes: or Link: line
$commit_log_possible_stack_dump)) {
WARN("COMMIT_LOG_LONG_LINE",
- "Possible unwrapped commit description (prefer a maximum 75 chars per line)\n" . $herecurr);
+ "Possible unwrapped commit description (prefer a maximum 72 chars per line)\n" . $herecurr);
$commit_log_long_line = 1;
}
@@ -2655,9 +2655,9 @@ sub process {
$commit_log_possible_stack_dump = 1;
}
-# Check for line lengths > 75 in commit log, warn once
+# Check for line lengths > 72 in commit log, warn once
if ($in_commit_log && !$commit_log_long_line &&